(layout)=

# Layout

The Layout Array module deals with the telescope positions and coordinate transformations.
It is used within CORSIKA Config and Array Model in order to encapsulate the information about the telescope positions.

(layoutarraymodule)=

## array_layout

```{eval-rst}
.. automodule:: layout.array_layout
   :members:

```

(telescopedatamodule)=

## telescope_position

```{eval-rst}
.. automodule:: layout.telescope_position
   :members:
```

(geocoordinatesmodule)=

## geo_coordinates

```{eval-rst}
.. automodule:: layout.geo_coordinates
   :members:
```

(array_layout_utils_module)=

## array_layout_utils

```{eval-rst}
.. automodule:: layout.array_layout_utils
   :members:
```
